/*
 * Created on Aug 16, 2005
 *
 * To change the template for this generated file go to
 * Window - Preferences - Java - Code Generation - Code and Comments
 */
package net.sf.freetime;

/**
 * Represents an individual row of CSV data.
 * @author robin
 */
public class CSVRow {

	private String[] values = null;
	
	/**
	 * Creates a new CSVRow with the specified
	 * number of columns.
	 * 
	 * @param columns
	 */
	public CSVRow(int columns) {
		values = new String[columns];
	}
	
	/**
	 * From a string of CSV data, parses it into a row
	 * @param s The string of data to parse
	 */
	public CSVRow(String s) {
		parse(s);
	}
	
	/**
	 * Parse the 
	 * @param data
	 */
	public void parse(String data) {
		
		// Split it up (I've not seen commas in the data
		// therefore they don't exist!)
		String[] b = Util.split(data, ",");
		
		for (int i = 0; i < b.length; i++) {
			// Remove any quotes
			b[i] = b[i].trim();
			if (b[i].startsWith("\""))
				b[i] = b[i].substring(1, b[i].length());
			if (b[i].endsWith("\""))
				b[i] = b[i].substring(0, b[i].length() - 1);
		}
		
		values = b;
		
	}
	
	/**
	 * Checks to see if this CSVRow is the same
	 * as another.
	 */
	public boolean equals(Object o) {
		if (o == null) return false;
		if (!(o instanceof CSVRow)) return false;
		CSVRow c = (CSVRow) o;
		boolean equal = true;
		for (int i = 0; i < c.getCount(); i++) {
			equal = equal && c.getValue(i).equals(values[i]);
		}
		return equal;
	}
	
	/** Returns the value in a particular column of the CSV, columns
	 *  are 0 based, running from 0 to count - 1 */
	public String getValue(int column) {
		return values[column];
	}
	
	/** Returns the number of values */
	public int getCount() {
		return values.length;
	}
	
	/** Stores a value in a column of the CSV. Columns
	 *  are zero based, running from 0 to count - 1 */
	public void putValue(int column, String value) {
		values[column] = value;
	}
	
	/** Outputs the data as a CSV row for writing to
	 *  a file. */
	public String toString() {
		StringBuffer b = new StringBuffer();
		for (int i = 0; i < values.length; i++) {
			if (i > 0) b.append(",");
			b.append("\"");
			b.append(values[i]);
			b.append("\"");
		}
		return b.toString();
	}

}
